#
# spec file for package python-PrettyTable
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Christian Berendt.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-PrettyTable
Version:        0.7.2
Release:        3.23
Summary:        Library for displaying tabular data in formatted fashion
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://prettytable.googlecode.com/files/prettytable-%{version}.tar.bz2
Source:         prettytable-%{version}.tar.bz2
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%ifpython2
Provides:       %{oldpython}-prettytable = 0.7.2
Obsoletes:      %{oldpython}-prettytable < 0.7.2
%endif
%python_subpackages

%description
PrettyTable is a Python library for representing tabular data in
ASCII tables, inspired by the tables emitted by the PostgreSQL shell,
psql. PrettyTable allows for selection of which columns are to be
printed, independent alignment of columns (left or right justified or
centred) and printing of "sub-tables" by specifying a row range.

%prep
%setup -q -n prettytable-%{version}
sed -i '1s/^#!.*//' prettytable.py

%build
%python_build

%install
%python_install

%check
export LANG=en_US.UTF-8
%python_exec setup.py test

%files %{python_files}
%doc CHANGELOG COPYING README
%{python_sitelib}/*

%changelog
* Tue Sep  5 2017 jengelh@inai.de
- Make description neutral.
* Fri Sep  1 2017 sebix+novell.com@sebix.at
- activate tests
- remove shebang from prettytable.py
- run spec-cleaner
* Wed Aug 23 2017 tbechtold@suse.com
- convert to singlespec
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Apr 26 2013 speilicke@suse.com
- Run testsuite
* Fri Feb 22 2013 saschpe@suse.de
- Use upstream URL and fix copyright
* Mon Feb 18 2013 p.drouand@gmail.com
- Update to version 0.7:
  + Improved Python 2 and 3 compatibility (2.4-3.2).
  + Improved support for non-Latin characters.  Table widths should
    now be calculated correctly for tables with e.g. Japanese text.
  + Table contents can now be read in from a .csv file
  + Table contents can now be read in from a DB-API compatible cursor
  + Table contents can now be read in from a string containing a
    HTML table
  + new valign attribute controls vertical alignment of text when
    some cells in a row have multiple lines of text and others don't.
  + hrules attribute can now be set to HEADER, which draws a rule only
    under the header row
  + new vrules attribute controls drawing of vertical rules and can
    be set to FRAME, ALL or NONE
  + new header_style attribute controls formatting of text in table
    headers and can be set to "cap", "title", "upper", "lower" or None
  + Fixed a simple bug regarding validation of max_width
  + Fixed a simple bug regarding initialisation of int_format value
    for new tables
  + Fixed a bug regarding some constructor keywords, such as "border",
    being ignored
* Thu Jul 26 2012 saschpe@suse.de
- Update to version 0.6.1:
  + Unicode encoding scheme can now be set by user
  + __str__ now uses user-specified encoding instead of ASCII.  This
  fixes a bug where tables with non-ASCII characters would print
  correctly with "print x.get_string()" but not "print x" in 2.x
  (thanks to Google Code user kevincobain2000 for reporting this
  bug!)
  + Fixed an incompatibility with 3.0 and 3.1 (html.escape was new
    in 3.2)
- Changes from version 0.6.0:
  + Code is now simultaneously compatible with Python 2 and 3
  + Replaced all setter methods with managed attributes
  + All styling options can now be set persistently as managed attributes
  + Added "add_style" method to make setting style options easily
  + Added "del_row", "clear_rows" and "clear" methods to facilitate
    removal of data from table.
  + Added "copy" method to facilitate cloning of a table.
  + Removed caching functionality, which added complexity and fragility
    for relatively little gain
  + Removed methods that just printed strings produced by get_string and
    get_html_string - just use inbuilt print!
  + Improved unicode support
  + Added support for decimal and floating point number formatting
    support
  + Added support for using a custom key sorting methods
  + Added support for line breaks in data
  + Added support for max column widths
  + Fixed table slicing
  + Fixed bug where closing <tr/> tags in HTML tables were not printed
  + Fixed HTML table sorting bug
  + Fixed bug whereby changing field_names did not recompute widths
* Wed Nov 30 2011 cfarrell@suse.com
- license update: BSD-2-Clause
  SPDX
* Tue Nov 29 2011 saschpe@suse.de
- Make it a noarch package
- %%py_requires needed for SLE
* Tue Nov 29 2011 idoenmez@suse.de
- Add license boilerplate
* Thu Nov 24 2011 idoenmez@suse.de
- Name field shouldn't contain a macro
* Wed Apr 20 2011 berendt@b1-systems.de
- created initial spec file using version 0.5
